@@ -84,7 +84,7 @@ class Operations(object):
     # When calling the APIs, in this case this is done in the resource class read function
     BANKS_CONF = {
         AUTHENTICATE: {
-            "url": "https://authserver.purplecliff-03d4fbdd.westeurope.azurecontainerapps.io",
+            "url": "https://authserver.dev.nashservices.nashglobal.co",
             "read": {
                 "operations": {
                     AUTH_GET_TOKEN: ("connect/token", "POST"),
