@@ -3,6 +3,8 @@ from django.utils import timezone
 
 
 class Callbacks(models.Model):
+    tenant_id = models.UUIDField(default=None, null=True, editable=False)
+    business_id = models.UUIDField(default=None, null=True, editable=False)
     bank_id = models.IntegerField()
     type_code = models.IntegerField()
     reference = models.CharField(max_length=100, unique=True)
@@ -20,7 +22,7 @@ class Callbacks(models.Model):
         return self.reference
 
     def __repr__(self):
-        return f'Callbacks(reference="{self.reference}",callback="{self.callback}", request={self.request}, response={self.response})'
+        return f'Callbacks(tenant_id="{self.tenant_id}",business_id="{self.business_id}",reference="{self.reference}",callback="{self.callback}", request={self.request}, response={self.response})'
 
 
 class RequestLogs(models.Model):
@@ -67,10 +69,13 @@ class ResponseLogs(models.Model):
 
 
 class IPN(models.Model):
+    tenant_id = models.UUIDField(default=None, null=True, editable=False)
+    business_id = models.UUIDField(default=None, null=True, editable=False)
     client_id = models.CharField(max_length=200, unique=True)
     signature = models.CharField(max_length=200, unique=True)
     bank_id = models.IntegerField()
     country_code = models.CharField(max_length=5, default='KE')
+    currency_code = models.CharField(max_length=5, default='KES')
     account_number = models.CharField(max_length=200, unique=True)
     url = models.URLField()
 
@@ -93,7 +98,7 @@ class IPN(models.Model):
         return f'{self.client_id} : I.P.N. Type - {[i[1] for i in self.IPNTYPE if i[0] == self.ipn_type][0]} : Status - {[i[1] for i in self.IPNSTATUS if i[0] == self.status][0]}'
 
     def __repr__(self):
-        return f'IPN(client_id="{self.client_id}", bank_id="{self.bank_id}", country_code="{self.country_code}", account_number="{self.account_number}", ipn_type={self.ipn_type}, status={self.status})'
+        return f'IPN(tenant_id="{self.tenant_id}",business_id="{self.business_id}",client_id="{self.client_id}", bank_id="{self.bank_id}", country_code="{self.country_code}", account_number="{self.account_number}", ipn_type={self.ipn_type}, status={self.status})'
 
 
 # This class is used to create/save user I.P.N. data sent back
